@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -149,7 +149,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
     }
 
     /**
-     * Write a byte to the buffer.
+     * Encodes a byte in the buffer.
      *
      * @param b
      *            byte to write
@@ -159,8 +159,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      *            the buffer to write to
      * @return the number of bytes that have been written to the buffer
      */
-    private static int encodeByte(final int b, final boolean encode,
-                                  final ByteArrayOutputStream buffer) {
+    private static int encodeByte(final int b, final boolean encode, final ByteArrayOutputStream buffer) {
         if (encode) {
             return encodeQuotedPrintable(b, buffer);
         }
@@ -282,10 +281,10 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      *            the buffer to write to
      * @return The number of bytes written to the {@code buffer}
      */
-    private static final int encodeQuotedPrintable(final int b, final ByteArrayOutputStream buffer) {
+    private static int encodeQuotedPrintable(final int b, final ByteArrayOutputStream buffer) {
         buffer.write(ESCAPE_CHAR);
-        final char hex1 = Utils.hexDigit(b >> 4);
-        final char hex2 = Utils.hexDigit(b);
+        final char hex1 = Utils.hexChar(b >> 4);
+        final char hex2 = Utils.hexChar(b);
         buffer.write(hex1);
         buffer.write(hex2);
         return 3;
@@ -388,8 +387,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      *
      * @since 1.7 throws UnsupportedCharsetException if the named Charset is unavailable
      */
-    public QuotedPrintableCodec(final String charsetName)
-            throws IllegalCharsetNameException, IllegalArgumentException, UnsupportedCharsetException {
+    public QuotedPrintableCodec(final String charsetName) throws IllegalCharsetNameException, IllegalArgumentException, UnsupportedCharsetException {
         this(Charset.forName(charsetName), false);
     }
 
@@ -434,9 +432,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
         if (obj instanceof String) {
             return decode((String) obj);
         }
-        throw new DecoderException("Objects of type " +
-              obj.getClass().getName() +
-              " cannot be quoted-printable decoded");
+        throw new DecoderException("Objects of type " + obj.getClass().getName() + " cannot be quoted-printable decoded");
     }
 
     /**
@@ -452,7 +448,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      */
     @Override
     public String decode(final String sourceStr) throws DecoderException {
-        return this.decode(sourceStr, this.getCharset());
+        return this.decode(sourceStr, getCharset());
     }
 
     /**
@@ -489,8 +485,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      * @throws UnsupportedEncodingException
      *             Thrown if Charset is not supported
      */
-    public String decode(final String sourceStr, final String sourceCharset)
-            throws DecoderException, UnsupportedEncodingException {
+    public String decode(final String sourceStr, final String sourceCharset) throws DecoderException, UnsupportedEncodingException {
         if (sourceStr == null) {
             return null;
         }
@@ -535,9 +530,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
         if (obj instanceof String) {
             return encode((String) obj);
         }
-        throw new EncoderException("Objects of type " +
-              obj.getClass().getName() +
-              " cannot be quoted-printable encoded");
+        throw new EncoderException("Objects of type " + obj.getClass().getName() + " cannot be quoted-printable encoded");
     }
 
     /**
@@ -558,7 +551,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      */
     @Override
     public String encode(final String sourceStr) throws EncoderException {
-        return this.encode(sourceStr, getCharset());
+        return encode(sourceStr, getCharset());
     }
 
     /**
