@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -31,13 +31,16 @@ import java.io.InputStream;
 import org.apache.commons.codec.CodecPolicy;
 import org.junit.jupiter.api.Test;
 
-public class Base32InputStreamTest {
+/**
+ * Tests {@link Base32InputStream}.
+ */
+class Base32InputStreamTest {
 
     private static final String ENCODED_FOO = "MZXW6===";
 
-    private final static byte[] CRLF = { (byte) '\r', (byte) '\n' };
+    private static final byte[] CRLF = { (byte) '\r', (byte) '\n' };
 
-    private final static byte[] LF = { (byte) '\n' };
+    private static final byte[] LF = { (byte) '\n' };
 
     private static final String STRING_FIXTURE = "Hello World";
 
@@ -48,9 +51,9 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testAvailable() throws Throwable {
+    void testAvailable() throws Throwable {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+        try (Base32InputStream b32stream = new Base32InputStream(ins)) {
             assertEquals(1, b32stream.available());
             assertEquals(3, b32stream.skip(10));
             // End of stream reached
@@ -75,7 +78,7 @@ public class Base32InputStreamTest {
     // * @throws Exception for some failure scenarios.
     // */
     // @Test
-    // public void testCodec101() throws Exception {
+    // void testCodec101() throws Exception {
     // byte[] codec101 = StringUtils.getBytesUtf8(Base32TestData.CODEC_101_MULTIPLE_OF_3);
     // ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
     // Base32InputStream in = new Base32InputStream(bais);
@@ -103,7 +106,7 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     // @Test
-    // public void testInputStreamReader() throws Exception {
+    // void testInputStreamReader() throws Exception {
     // byte[] codec101 = StringUtils.getBytesUtf8(Base32TestData.CODEC_101_MULTIPLE_OF_3);
     // ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
     // Base32InputStream in = new Base32InputStream(bais);
@@ -120,7 +123,7 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     // @Test
-    // public void testCodec98NPE() throws Exception {
+    // void testCodec98NPE() throws Exception {
     // byte[] codec98 = StringUtils.getBytesUtf8(Base32TestData.CODEC_98_NPE);
     // ByteArrayInputStream data = new ByteArrayInputStream(codec98);
     // Base32InputStream stream = new Base32InputStream(data);
@@ -141,7 +144,7 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testBase32EmptyInputStreamMimeChuckSize() throws Exception {
+    void testBase32EmptyInputStreamMimeChuckSize() throws Exception {
         testBase32EmptyInputStream(BaseNCodec.MIME_CHUNK_SIZE);
     }
 
@@ -152,7 +155,7 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testBase32EmptyInputStreamPemChuckSize() throws Exception {
+    void testBase32EmptyInputStreamPemChuckSize() throws Exception {
         testBase32EmptyInputStream(BaseNCodec.PEM_CHUNK_SIZE);
     }
 
@@ -163,7 +166,7 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testBase32InputStreamByChunk() throws Exception {
+    void testBase32InputStreamByChunk() throws Exception {
         // Hello World test.
         byte[] encoded = StringUtils.getBytesUtf8(Base32TestData.BASE32_FIXTURE);
         byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
@@ -202,7 +205,7 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testBase32InputStreamByteByByte() throws Exception {
+    void testBase32InputStreamByteByByte() throws Exception {
         // Hello World test.
         byte[] encoded = StringUtils.getBytesUtf8(Base32TestData.BASE32_FIXTURE);
         byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
@@ -248,33 +251,28 @@ public class Base32InputStreamTest {
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
     private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
-
         // Start with encode.
-        InputStream in;
-
-        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
-        byte[] output = BaseNTestData.streamToBytes(in);
-
-        assertEquals(-1, in.read(), "EOF");
-        assertEquals(-1, in.read(), "Still EOF");
-        assertArrayEquals(encoded, output, "Streaming base32 encode");
-
+        try (InputStream in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator)) {
+            final byte[] output = BaseNTestData.streamToBytes(in);
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(encoded, output, "Streaming base32 encode");
+        }
         // Now let's try to decode.
-        in = new Base32InputStream(new ByteArrayInputStream(encoded));
-        output = BaseNTestData.streamToBytes(in);
-
-        assertEquals(-1, in.read(), "EOF");
-        assertEquals(-1, in.read(), "Still EOF");
-        assertArrayEquals(decoded, output, "Streaming base32 decode");
+        try (InputStream in = new Base32InputStream(new ByteArrayInputStream(encoded))) {
+            final byte[] output = BaseNTestData.streamToBytes(in);
 
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(decoded, output, "Streaming base32 decode");
+        }
         // I always wanted to do this! (wrap encoder with decoder etc.).
-        in = new ByteArrayInputStream(decoded);
+        InputStream in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
             in = new Base32InputStream(in, true, chunkSize, separator);
             in = new Base32InputStream(in, false);
         }
-        output = BaseNTestData.streamToBytes(in);
-
+        final byte[] output = BaseNTestData.streamToBytes(in);
         assertEquals(-1, in.read(), "EOF");
         assertEquals(-1, in.read(), "Still EOF");
         assertArrayEquals(decoded, output, "Streaming base32 wrap-wrap-wrap!");
@@ -348,8 +346,8 @@ public class Base32InputStreamTest {
      * Tests the bug reported in CODEC-105. Bad interactions with InputStream when reading one byte at a time.
      */
     @Test
-    public void testCodec105() throws IOException {
-        try (final Base32InputStream in = new Base32InputStream(new Codec105ErrorInputStream(), true, 0, null)) {
+    void testCodec105() throws IOException {
+        try (Base32InputStream in = new Base32InputStream(new Codec105ErrorInputStream(), true, 0, null)) {
             for (int i = 0; i < 5; i++) {
                 in.read();
             }
@@ -360,9 +358,9 @@ public class Base32InputStreamTest {
      * Tests the problem reported in CODEC-130. Missing / wrong implementation of skip.
      */
     @Test
-    public void testCodec130() throws IOException {
+    void testCodec130() throws IOException {
         final ByteArrayOutputStream bos = new ByteArrayOutputStream();
-        try (final Base32OutputStream base32os = new Base32OutputStream(bos)) {
+        try (Base32OutputStream base32os = new Base32OutputStream(bos)) {
             base32os.write(StringUtils.getBytesUtf8(STRING_FIXTURE));
         }
 
@@ -384,10 +382,10 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testMarkSupported() throws Exception {
+    void testMarkSupported() throws Exception {
         final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
+        try (Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
             // Always returns false for now.
             assertFalse(in.markSupported(), "Base32InputStream.markSupported() is false");
         }
@@ -400,12 +398,12 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testRead0() throws Exception {
+    void testRead0() throws Exception {
         final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
         final byte[] buf = new byte[1024];
         int bytesRead = 0;
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
+        try (Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
             bytesRead = in.read(buf, 0, 0);
             assertEquals(0, bytesRead, "Base32InputStream.read(buf, 0, 0) returns 0");
         }
@@ -418,10 +416,10 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testReadNull() throws Exception {
+    void testReadNull() throws Exception {
         final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] {0, 0, 0})) {
+        try (Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] {0, 0, 0})) {
             assertThrows(NullPointerException.class, () -> in.read(null, 0, 0));
         }
     }
@@ -433,11 +431,11 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testReadOutOfBounds() throws Exception {
+    void testReadOutOfBounds() throws Exception {
         final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
         final byte[] buf = new byte[1024];
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
+        try (Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
             assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, -1, 0), "Base32InputStream.read(buf, -1, 0)");
             assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, 0, -1), "Base32InputStream.read(buf, 0, -1)");
             assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length + 1, 0), "Base32InputStream.read(buf, buf.length + 1, 0)");
@@ -452,9 +450,9 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testSkipBig() throws Throwable {
+    void testSkipBig() throws Throwable {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+        try (Base32InputStream b32stream = new Base32InputStream(ins)) {
             assertEquals(3, b32stream.skip(1024));
             // End of stream reached
             assertEquals(-1, b32stream.read());
@@ -469,9 +467,9 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testSkipNone() throws Throwable {
+    void testSkipNone() throws Throwable {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+        try (Base32InputStream b32stream = new Base32InputStream(ins)) {
             final byte[] actualBytes = new byte[6];
             assertEquals(0, b32stream.skip(0));
             b32stream.read(actualBytes, 0, actualBytes.length);
@@ -488,9 +486,9 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testSkipPastEnd() throws Throwable {
+    void testSkipPastEnd() throws Throwable {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+        try (Base32InputStream b32stream = new Base32InputStream(ins)) {
             // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
             assertEquals(3, b32stream.skip(10));
             // End of stream reached
@@ -506,9 +504,9 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testSkipToEnd() throws Throwable {
+    void testSkipToEnd() throws Throwable {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+        try (Base32InputStream b32stream = new Base32InputStream(ins)) {
             // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
             assertEquals(3, b32stream.skip(3));
             // End of stream reached
@@ -524,9 +522,9 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testSkipWrongArgument() throws Throwable {
+    void testSkipWrongArgument() throws Throwable {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+        try (Base32InputStream b32stream = new Base32InputStream(ins)) {
             assertThrows(IllegalArgumentException.class, () -> b32stream.skip(-10));
         }
     }
@@ -538,7 +536,7 @@ public class Base32InputStreamTest {
      *             for some failure scenarios.
      */
     @Test
-    public void testStrictDecoding() throws Exception {
+    void testStrictDecoding() throws Exception {
         for (final String s : Base32Test.BASE32_IMPOSSIBLE_CASES) {
             final byte[] encoded = StringUtils.getBytesUtf8(s);
             final Base32InputStream in = new Base32InputStream(new ByteArrayInputStream(encoded), false);
