@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -32,7 +32,7 @@ import org.junit.jupiter.api.Test;
  *
  * <p>Keep this file in UTF-8 encoding for proper Javadoc processing.</p>
  */
-public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
+class SoundexTest extends AbstractStringEncoderTest<Soundex> {
 
     @Override
     protected Soundex createStringEncoder() {
@@ -40,8 +40,8 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
     }
 
     @Test
-    public void testB650() throws EncoderException {
-        this.checkEncodingVariations("B650", new String[]{
+    void testB650() throws EncoderException {
+        checkEncodingVariations("B650", new String[]{
             "BARHAM",
             "BARONE",
             "BARRON",
@@ -85,103 +85,103 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
     }
 
     @Test
-    public void testBadCharacters() {
-        assertEquals("H452", this.getStringEncoder().encode("HOL>MES"));
+    void testBadCharacters() {
+        assertEquals("H452", getStringEncoder().encode("HOL>MES"));
 
     }
 
     @Test
-    public void testDifference() throws EncoderException {
+    void testDifference() throws EncoderException {
         // Edge cases
-        assertEquals(0, this.getStringEncoder().difference(null, null));
-        assertEquals(0, this.getStringEncoder().difference("", ""));
-        assertEquals(0, this.getStringEncoder().difference(" ", " "));
+        assertEquals(0, getStringEncoder().difference(null, null));
+        assertEquals(0, getStringEncoder().difference("", ""));
+        assertEquals(0, getStringEncoder().difference(" ", " "));
         // Normal cases
-        assertEquals(4, this.getStringEncoder().difference("Smith", "Smythe"));
-        assertEquals(2, this.getStringEncoder().difference("Ann", "Andrew"));
-        assertEquals(1, this.getStringEncoder().difference("Margaret", "Andrew"));
-        assertEquals(0, this.getStringEncoder().difference("Janet", "Margaret"));
+        assertEquals(4, getStringEncoder().difference("Smith", "Smythe"));
+        assertEquals(2, getStringEncoder().difference("Ann", "Andrew"));
+        assertEquals(1, getStringEncoder().difference("Margaret", "Andrew"));
+        assertEquals(0, getStringEncoder().difference("Janet", "Margaret"));
         // Examples from https://msdn.microsoft.com/library/default.asp?url=/library/en-us/tsqlref/ts_de-dz_8co5.asp
-        assertEquals(4, this.getStringEncoder().difference("Green", "Greene"));
-        assertEquals(0, this.getStringEncoder().difference("Blotchet-Halls", "Greene"));
+        assertEquals(4, getStringEncoder().difference("Green", "Greene"));
+        assertEquals(0, getStringEncoder().difference("Blotchet-Halls", "Greene"));
         // Examples from https://msdn.microsoft.com/library/default.asp?url=/library/en-us/tsqlref/ts_setu-sus_3o6w.asp
-        assertEquals(4, this.getStringEncoder().difference("Smith", "Smythe"));
-        assertEquals(4, this.getStringEncoder().difference("Smithers", "Smythers"));
-        assertEquals(2, this.getStringEncoder().difference("Anothers", "Brothers"));
+        assertEquals(4, getStringEncoder().difference("Smith", "Smythe"));
+        assertEquals(4, getStringEncoder().difference("Smithers", "Smythers"));
+        assertEquals(2, getStringEncoder().difference("Anothers", "Brothers"));
     }
 
     @Test
-    public void testEncodeBasic() {
-        assertEquals("T235", this.getStringEncoder().encode("testing"));
-        assertEquals("T000", this.getStringEncoder().encode("The"));
-        assertEquals("Q200", this.getStringEncoder().encode("quick"));
-        assertEquals("B650", this.getStringEncoder().encode("brown"));
-        assertEquals("F200", this.getStringEncoder().encode("fox"));
-        assertEquals("J513", this.getStringEncoder().encode("jumped"));
-        assertEquals("O160", this.getStringEncoder().encode("over"));
-        assertEquals("T000", this.getStringEncoder().encode("the"));
-        assertEquals("L200", this.getStringEncoder().encode("lazy"));
-        assertEquals("D200", this.getStringEncoder().encode("dogs"));
+    void testEncodeBasic() {
+        assertEquals("T235", getStringEncoder().encode("testing"));
+        assertEquals("T000", getStringEncoder().encode("The"));
+        assertEquals("Q200", getStringEncoder().encode("quick"));
+        assertEquals("B650", getStringEncoder().encode("brown"));
+        assertEquals("F200", getStringEncoder().encode("fox"));
+        assertEquals("J513", getStringEncoder().encode("jumped"));
+        assertEquals("O160", getStringEncoder().encode("over"));
+        assertEquals("T000", getStringEncoder().encode("the"));
+        assertEquals("L200", getStringEncoder().encode("lazy"));
+        assertEquals("D200", getStringEncoder().encode("dogs"));
     }
 
     /**
      * Examples from http://www.bradandkathy.com/genealogy/overviewofsoundex.html
      */
     @Test
-    public void testEncodeBatch2() {
-        assertEquals("A462", this.getStringEncoder().encode("Allricht"));
-        assertEquals("E166", this.getStringEncoder().encode("Eberhard"));
-        assertEquals("E521", this.getStringEncoder().encode("Engebrethson"));
-        assertEquals("H512", this.getStringEncoder().encode("Heimbach"));
-        assertEquals("H524", this.getStringEncoder().encode("Hanselmann"));
-        assertEquals("H431", this.getStringEncoder().encode("Hildebrand"));
-        assertEquals("K152", this.getStringEncoder().encode("Kavanagh"));
-        assertEquals("L530", this.getStringEncoder().encode("Lind"));
-        assertEquals("L222", this.getStringEncoder().encode("Lukaschowsky"));
-        assertEquals("M235", this.getStringEncoder().encode("McDonnell"));
-        assertEquals("M200", this.getStringEncoder().encode("McGee"));
-        assertEquals("O155", this.getStringEncoder().encode("Opnian"));
-        assertEquals("O155", this.getStringEncoder().encode("Oppenheimer"));
-        assertEquals("R355", this.getStringEncoder().encode("Riedemanas"));
-        assertEquals("Z300", this.getStringEncoder().encode("Zita"));
-        assertEquals("Z325", this.getStringEncoder().encode("Zitzmeinn"));
+    void testEncodeBatch2() {
+        assertEquals("A462", getStringEncoder().encode("Allricht"));
+        assertEquals("E166", getStringEncoder().encode("Eberhard"));
+        assertEquals("E521", getStringEncoder().encode("Engebrethson"));
+        assertEquals("H512", getStringEncoder().encode("Heimbach"));
+        assertEquals("H524", getStringEncoder().encode("Hanselmann"));
+        assertEquals("H431", getStringEncoder().encode("Hildebrand"));
+        assertEquals("K152", getStringEncoder().encode("Kavanagh"));
+        assertEquals("L530", getStringEncoder().encode("Lind"));
+        assertEquals("L222", getStringEncoder().encode("Lukaschowsky"));
+        assertEquals("M235", getStringEncoder().encode("McDonnell"));
+        assertEquals("M200", getStringEncoder().encode("McGee"));
+        assertEquals("O155", getStringEncoder().encode("Opnian"));
+        assertEquals("O155", getStringEncoder().encode("Oppenheimer"));
+        assertEquals("R355", getStringEncoder().encode("Riedemanas"));
+        assertEquals("Z300", getStringEncoder().encode("Zita"));
+        assertEquals("Z325", getStringEncoder().encode("Zitzmeinn"));
     }
 
     /**
      * Examples from http://www.archives.gov/research_room/genealogy/census/soundex.html
      */
     @Test
-    public void testEncodeBatch3() {
-        assertEquals("W252", this.getStringEncoder().encode("Washington"));
-        assertEquals("L000", this.getStringEncoder().encode("Lee"));
-        assertEquals("G362", this.getStringEncoder().encode("Gutierrez"));
-        assertEquals("P236", this.getStringEncoder().encode("Pfister"));
-        assertEquals("J250", this.getStringEncoder().encode("Jackson"));
-        assertEquals("T522", this.getStringEncoder().encode("Tymczak"));
+    void testEncodeBatch3() {
+        assertEquals("W252", getStringEncoder().encode("Washington"));
+        assertEquals("L000", getStringEncoder().encode("Lee"));
+        assertEquals("G362", getStringEncoder().encode("Gutierrez"));
+        assertEquals("P236", getStringEncoder().encode("Pfister"));
+        assertEquals("J250", getStringEncoder().encode("Jackson"));
+        assertEquals("T522", getStringEncoder().encode("Tymczak"));
         // For VanDeusen: D-250 (D, 2 for the S, 5 for the N, 0 added) is also
         // possible.
-        assertEquals("V532", this.getStringEncoder().encode("VanDeusen"));
+        assertEquals("V532", getStringEncoder().encode("VanDeusen"));
     }
 
     /**
      * Examples from: http://www.myatt.demon.co.uk/sxalg.htm
      */
     @Test
-    public void testEncodeBatch4() {
-        assertEquals("H452", this.getStringEncoder().encode("HOLMES"));
-        assertEquals("A355", this.getStringEncoder().encode("ADOMOMI"));
-        assertEquals("V536", this.getStringEncoder().encode("VONDERLEHR"));
-        assertEquals("B400", this.getStringEncoder().encode("BALL"));
-        assertEquals("S000", this.getStringEncoder().encode("SHAW"));
-        assertEquals("J250", this.getStringEncoder().encode("JACKSON"));
-        assertEquals("S545", this.getStringEncoder().encode("SCANLON"));
-        assertEquals("S532", this.getStringEncoder().encode("SAINTJOHN"));
+    void testEncodeBatch4() {
+        assertEquals("H452", getStringEncoder().encode("HOLMES"));
+        assertEquals("A355", getStringEncoder().encode("ADOMOMI"));
+        assertEquals("V536", getStringEncoder().encode("VONDERLEHR"));
+        assertEquals("B400", getStringEncoder().encode("BALL"));
+        assertEquals("S000", getStringEncoder().encode("SHAW"));
+        assertEquals("J250", getStringEncoder().encode("JACKSON"));
+        assertEquals("S545", getStringEncoder().encode("SCANLON"));
+        assertEquals("S532", getStringEncoder().encode("SAINTJOHN"));
 
     }
 
     @Test
-    public void testEncodeIgnoreApostrophes() throws EncoderException {
-        this.checkEncodingVariations("O165", new String[]{
+    void testEncodeIgnoreApostrophes() throws EncoderException {
+        checkEncodingVariations("O165", new String[]{
             "OBrien",
             "'OBrien",
             "O'Brien",
@@ -197,8 +197,8 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      *
      * @throws EncoderException for some failure scenarios     */
     @Test
-    public void testEncodeIgnoreHyphens() throws EncoderException {
-        this.checkEncodingVariations("K525", new String[]{
+    void testEncodeIgnoreHyphens() throws EncoderException {
+        checkEncodingVariations("K525", new String[]{
             "KINGSMITH",
             "-KINGSMITH",
             "K-INGSMITH",
@@ -213,13 +213,13 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
     }
 
     @Test
-    public void testEncodeIgnoreTrimmable() {
-        assertEquals("W252", this.getStringEncoder().encode(" \t\n\r Washington \t\n\r "));
+    void testEncodeIgnoreTrimmable() {
+        assertEquals("W252", getStringEncoder().encode(" \t\n\r Washington \t\n\r "));
     }
 
     @Test
 // examples and algorithm rules from:  http://www.genealogy.com/articles/research/00000060.html
-    public void testGenealogy() { // treat vowels and HW as silent
+    void testGenealogy() { // treat vowels and HW as silent
         final Soundex s = Soundex.US_ENGLISH_GENEALOGY;
         assertEquals("H251", s.encode("Heggenburger"));
         assertEquals("B425", s.encode("Blackman"));
@@ -235,15 +235,15 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      * Consonants from the same code group separated by W or H are treated as one.
      */
     @Test
-    public void testHWRuleEx1() {
+    void testHWRuleEx1() {
         // From
         // http://www.archives.gov/research_room/genealogy/census/soundex.html:
         // Ashcraft is coded A-261 (A, 2 for the S, C ignored, 6 for the R, 1
         // for the F). It is not coded A-226.
-        assertEquals("A261", this.getStringEncoder().encode("Ashcraft"));
-        assertEquals("A261", this.getStringEncoder().encode("Ashcroft"));
-        assertEquals("Y330", this.getStringEncoder().encode("yehudit"));
-        assertEquals("Y330", this.getStringEncoder().encode("yhwdyt"));
+        assertEquals("A261", getStringEncoder().encode("Ashcraft"));
+        assertEquals("A261", getStringEncoder().encode("Ashcroft"));
+        assertEquals("Y330", getStringEncoder().encode("yehudit"));
+        assertEquals("Y330", getStringEncoder().encode("yhwdyt"));
     }
 
     /**
@@ -252,9 +252,9 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      * Test data from http://www.myatt.demon.co.uk/sxalg.htm
      */
     @Test
-    public void testHWRuleEx2() {
-        assertEquals("B312", this.getStringEncoder().encode("BOOTHDAVIS"));
-        assertEquals("B312", this.getStringEncoder().encode("BOOTH-DAVIS"));
+    void testHWRuleEx2() {
+        assertEquals("B312", getStringEncoder().encode("BOOTHDAVIS"));
+        assertEquals("B312", getStringEncoder().encode("BOOTH-DAVIS"));
     }
 
     /**
@@ -262,11 +262,11 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      *
      * @throws EncoderException for some failure scenarios     */
     @Test
-    public void testHWRuleEx3() throws EncoderException {
-        assertEquals("S460", this.getStringEncoder().encode("Sgler"));
-        assertEquals("S460", this.getStringEncoder().encode("Swhgler"));
+    void testHWRuleEx3() throws EncoderException {
+        assertEquals("S460", getStringEncoder().encode("Sgler"));
+        assertEquals("S460", getStringEncoder().encode("Swhgler"));
         // Also S460:
-        this.checkEncodingVariations("S460", new String[]{
+        checkEncodingVariations("S460", new String[]{
             "SAILOR",
             "SALYER",
             "SAYLOR",
@@ -290,9 +290,9 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      * https://msdn.microsoft.com/library/default.asp?url=/library/en-us/tsqlref/ts_setu-sus_3o6w.asp
      */
     @Test
-    public void testMsSqlServer1() {
-        assertEquals("S530", this.getStringEncoder().encode("Smith"));
-        assertEquals("S530", this.getStringEncoder().encode("Smythe"));
+    void testMsSqlServer1() {
+        assertEquals("S530", getStringEncoder().encode("Smith"));
+        assertEquals("S530", getStringEncoder().encode("Smythe"));
     }
 
     /**
@@ -302,47 +302,47 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      *
      * @throws EncoderException for some failure scenarios     */
     @Test
-    public void testMsSqlServer2() throws EncoderException {
-        this.checkEncodingVariations("E625", new String[]{"Erickson", "Erickson", "Erikson", "Ericson", "Ericksen", "Ericsen"});
+    void testMsSqlServer2() throws EncoderException {
+        checkEncodingVariations("E625", new String[]{"Erickson", "Erickson", "Erikson", "Ericson", "Ericksen", "Ericsen"});
     }
 
     /**
      * Examples for MS SQLServer from https://databases.about.com/library/weekly/aa042901a.htm
      */
     @Test
-    public void testMsSqlServer3() {
-        assertEquals("A500", this.getStringEncoder().encode("Ann"));
-        assertEquals("A536", this.getStringEncoder().encode("Andrew"));
-        assertEquals("J530", this.getStringEncoder().encode("Janet"));
-        assertEquals("M626", this.getStringEncoder().encode("Margaret"));
-        assertEquals("S315", this.getStringEncoder().encode("Steven"));
-        assertEquals("M240", this.getStringEncoder().encode("Michael"));
-        assertEquals("R163", this.getStringEncoder().encode("Robert"));
-        assertEquals("L600", this.getStringEncoder().encode("Laura"));
-        assertEquals("A500", this.getStringEncoder().encode("Anne"));
+    void testMsSqlServer3() {
+        assertEquals("A500", getStringEncoder().encode("Ann"));
+        assertEquals("A536", getStringEncoder().encode("Andrew"));
+        assertEquals("J530", getStringEncoder().encode("Janet"));
+        assertEquals("M626", getStringEncoder().encode("Margaret"));
+        assertEquals("S315", getStringEncoder().encode("Steven"));
+        assertEquals("M240", getStringEncoder().encode("Michael"));
+        assertEquals("R163", getStringEncoder().encode("Robert"));
+        assertEquals("L600", getStringEncoder().encode("Laura"));
+        assertEquals("A500", getStringEncoder().encode("Anne"));
     }
 
     /**
      * https://issues.apache.org/jira/browse/CODEC-54 https://issues.apache.org/jira/browse/CODEC-56
      */
     @Test
-    public void testNewInstance() {
+    void testNewInstance() {
         assertEquals("W452", new Soundex().soundex("Williams"));
     }
 
     @Test
-    public void testNewInstance2() {
+    void testNewInstance2() {
         assertEquals("W452", new Soundex(Soundex.US_ENGLISH_MAPPING_STRING.toCharArray()).soundex("Williams"));
     }
 
     @Test
-    public void testNewInstance3() {
+    void testNewInstance3() {
         assertEquals("W452", new Soundex(Soundex.US_ENGLISH_MAPPING_STRING).soundex("Williams"));
     }
 
     @Test
 // examples and algorithm rules from:  http://west-penwith.org.uk/misc/soundex.htm
-    public void testSimplifiedSoundex() { // treat vowels and HW as separators
+    void testSimplifiedSoundex() { // treat vowels and HW as separators
         final Soundex s = Soundex.US_ENGLISH_SIMPLIFIED;
         assertEquals("W452", s.encode("WILLIAMS"));
         assertEquals("B625", s.encode("BARAGWANATH"));
@@ -356,12 +356,12 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
     }
 
     @Test
-    public void testSoundexUtilsConstructable() {
+    void testSoundexUtilsConstructable() {
         new SoundexUtils();
     }
 
     @Test
-    public void testSoundexUtilsNullBehaviour() {
+    void testSoundexUtilsNullBehaviour() {
         assertNull(SoundexUtils.clean(null));
         assertEquals("", SoundexUtils.clean(""));
         assertEquals(0, SoundexUtils.differenceEncoded(null, ""));
@@ -372,7 +372,7 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      * https://issues.apache.org/jira/browse/CODEC-54 https://issues.apache.org/jira/browse/CODEC-56
      */
     @Test
-    public void testUsEnglishStatic() {
+    void testUsEnglishStatic() {
         assertEquals("W452", Soundex.US_ENGLISH.soundex("Williams"));
     }
 
@@ -382,13 +382,13 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      * https://issues.apache.org/jira/browse/CODEC-30
      */
     @Test
-    public void testUsMappingEWithAcute() {
-        assertEquals("E000", this.getStringEncoder().encode("e"));
+    void testUsMappingEWithAcute() {
+        assertEquals("E000", getStringEncoder().encode("e"));
         if (Character.isLetter('\u00e9')) { // e-acute
             //         uppercase E-acute
             assertThrows(IllegalArgumentException.class, () -> getStringEncoder().encode("\u00e9"));
         } else {
-            assertEquals("", this.getStringEncoder().encode("\u00e9"));
+            assertEquals("", getStringEncoder().encode("\u00e9"));
         }
     }
 
@@ -398,13 +398,13 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      * https://issues.apache.org/jira/browse/CODEC-30
      */
     @Test
-    public void testUsMappingOWithDiaeresis() {
-        assertEquals("O000", this.getStringEncoder().encode("o"));
+    void testUsMappingOWithDiaeresis() {
+        assertEquals("O000", getStringEncoder().encode("o"));
         if (Character.isLetter('\u00f6')) { // o-umlaut
             //         uppercase O-umlaut
             assertThrows(IllegalArgumentException.class, () -> getStringEncoder().encode("\u00f6"));
         } else {
-            assertEquals("", this.getStringEncoder().encode("\u00f6"));
+            assertEquals("", getStringEncoder().encode("\u00f6"));
         }
     }
 
@@ -412,12 +412,12 @@ public class SoundexTest extends AbstractStringEncoderTest<Soundex> {
      * Tests example from https://en.wikipedia.org/wiki/Soundex#American_Soundex as of 2015-03-22.
      */
     @Test
-    public void testWikipediaAmericanSoundex() {
-        assertEquals("R163", this.getStringEncoder().encode("Robert"));
-        assertEquals("R163", this.getStringEncoder().encode("Rupert"));
-        assertEquals("A261", this.getStringEncoder().encode("Ashcraft"));
-        assertEquals("A261", this.getStringEncoder().encode("Ashcroft"));
-        assertEquals("T522", this.getStringEncoder().encode("Tymczak"));
-        assertEquals("P236", this.getStringEncoder().encode("Pfister"));
+    void testWikipediaAmericanSoundex() {
+        assertEquals("R163", getStringEncoder().encode("Robert"));
+        assertEquals("R163", getStringEncoder().encode("Rupert"));
+        assertEquals("A261", getStringEncoder().encode("Ashcraft"));
+        assertEquals("A261", getStringEncoder().encode("Ashcroft"));
+        assertEquals("T522", getStringEncoder().encode("Tymczak"));
+        assertEquals("P236", getStringEncoder().encode("Pfister"));
     }
 }
